Image visualization plugins for the wai.annotations library:

* `add-annotation-overlay-ic`: adds image classification overlays to images
* `add-annotation-overlay-is`: adds image segmentation overlays to images
* `add-annotation-overlay-od`: adds object detection overlays to images
* `image-viewer-ic`: sink for displaying image classification images
* `image-viewer-is`: sink for displaying image segmentation images
* `image-viewer-od`: sink for displaying object detection images
* `to-annotation-overlay-od`: generates an image with all the annotation shapes (bbox or polygon) overlayed
